# Run meta-analysis of drainage effects vs distance

require(metafor)
library(openxlsx)
library(stringr)

output_dir = "C:/wetlands/regr_drain"
setwd(output_dir)

# Function definitions
# ----------------------
mlabfun <- function(text, res) {
   paste(text, 
#   " (Q =", (formatC(res$QE, digits=2, format="f")),
#  ", df =", (res$k - res$p),
#   ", I^2 =", (formatC(res$I2, digits=1, format="f")), "%, ",
#   "tau^2 =", (formatC(res$tau2, digits=2, format="f")),
#    ")"
""
)}

# Constants
# ----------------------

# No of decimal digits for forest plot rows
decimals_rows = 0
# No of decimal digits for forest plot axis tick labels
decimals_axis = 0

# Start of program
# ----------------------

# Load data from combined effect size file
esd <- read.xlsx("C:/wetlands/Additional file 5.xlsx")

# Update header
names(esd) <- esd[1,]

# Drop first row of data (the second row of header information)
esd <- esd[-c(1), ]

# Drop treatment categories that are not drainage
esd <- esd[(esd$"Drainage/Restoration/Creation" == "Drainage"),]

# Drop rows without treatment id (not included in meta-analysis)
esd <- esd[!(is.na(esd$"Regression Treatment ID")),]

# Remove study Essery 1990 #10490 as this is a floodplain whereas the remainder of wetlands are peatlands
# This study should be exempt from the meta-analysis
esd <- esd[!(esd$"Covidence id" == "#10490"),]

# Drop Lundin 1984 as this is a study of the effects outside the wetland
# It is therefore not comparable to the within-wetland soil studies
esd <- esd[!(esd$"Covidence id" == "#10690"),]

# Set data types for some columns we need in the analysis
esd$"Regression slope" <- as.numeric(esd$"Regression slope")
esd$"Regression slope.SE" <- as.numeric(esd$"Regression slope.SE")
esd$"Regression intercept" <- as.numeric(esd$"Regression intercept")
esd$"Regression intercept.SE" <- as.numeric(esd$"Regression intercept.SE")
esd$"Average or estimated ditch spacing (m)" <- as.numeric(esd$"Average or estimated ditch spacing (m)")
esd$"Average peat depth (cm)" <- as.numeric(esd$"Average peat depth (cm)")
esd$"Time since intervetion (min, yrs)" <- as.numeric(esd$"Time since intervetion (min, yrs)") 
esd$"Time since intervetion (max, yrs)" <- as.numeric(esd$"Time since intervetion (max, yrs)") 
esd$"Intervention magnitude (depth/height in cm)" <- as.numeric(esd$"Intervention magnitude (depth/height in cm)")
esd$"Slope (degrees)" <- as.numeric(esd$"Slope (degrees)")
esd$"Maximum distance of gwl measurements (m)" <- as.numeric(esd$"Maximum distance of gwl measurements (m)")

# Rename a few columns we need to work with in metafor (which can't handle column names in quotes)
names(esd)[names(esd) == "Regression slope"] <- "Regr_slope"
names(esd)[names(esd) == "Regression slope.SE"] <- "Regr_slope_SE"
names(esd)[names(esd) == "Regression intercept"] <- "Regr_intercept"
names(esd)[names(esd) == "Regression intercept.SE"] <- "Regr_intercept_SE"
names(esd)[names(esd) == "Wetland type"] <- "Wetland_type"
names(esd)[names(esd) == "Climate zone"] <- "Climate_zone"
names(esd)[names(esd) == "Average peat depth (cm)"] <- "Peat_depth"
names(esd)[names(esd) == "Average or estimated ditch spacing (m)"] <- "Ditch_spacing"
names(esd)[names(esd) == "True replications (intervention level, count only intervention sites, not control)"] <- "True_reps"
names(esd)[names(esd) == "Time since intervetion (min, yrs)"] <- "Time_since_intervention_min"
names(esd)[names(esd) == "Time since intervetion (max, yrs)"] <- "Time_since_intervention_max"
names(esd)[names(esd) == "Underlying soil type"] <- "Underlying_soil"
names(esd)[names(esd) == "Short ref"] <- "Short_ref"
names(esd)[names(esd) == "Original order"] <- "Original_order"
names(esd)[names(esd) == "Intervention magnitude (depth/height in cm)"] <- "Intervention_magnitude"
names(esd)[names(esd) == "Slope (degrees)"] <- "Slope"
names(esd)[names(esd) == "Maximum distance of gwl measurements (m)"] <- "Max_dist_for_gwl_sampling"
names(esd)[names(esd) == "Confined/mirrored (by next ditch) or open-ended transect"] <- "Transect_type"
names(esd)[names(esd) == "Groundwater level reference point"] <- "Gwl_ref_point"


# Make a new column with average time since intervention
esd$Time_since_intervention_avg <- rowMeans(esd[,c("Time_since_intervention_min", "Time_since_intervention_max")], na.rm=TRUE)

# Sort by column Wetland_type, then Short_ref, then first col (original row number in metadata table)
esd <- esd[with(esd, order(Wetland_type, Short_ref, Original_order)), ]


# Perform a meta-analysis of regression slopes
# --------------------------------------------
# Calculate RE model based on underlying sample size (number of true replications) weights = True_reps
result = rma(measure = "MD", data = esd, yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

# Set up data frame to save meta-analysis results
df <- data.frame(value = c("slope_main_all"), estimate = c(result$b), SE = c(result$se), ci.lb = c(result$ci.lb), ci.ub = c(result$ci.ub), k = c(result$k), pval = c(result$pval), tau2 = c(result$tau2), I2 = c(result$I2), H2 = c(result$H2), QE = c(result$QE), QEp = c(result$QEp), QM = c(NA), QMp = c(NA))

# Plotting 
# --------------------------------------------
# Count rows for each wetland type
# Needs to be adjusted for different number of groups
group_rowcounts = table(esd$Wetland_type)

# We want the cumulative no of rows in reverse alphabetical order for plotting (unspecified peatland, mire, fen, bog)
group_cum_rowcounts = cumsum(rev(group_rowcounts))

# Start rows (counting from bottom end of table) for the wetland types
group_start_rows = c(3, group_cum_rowcounts[1] + 7, 
				group_cum_rowcounts[2] + 11, 
				group_cum_rowcounts[3] + 15)

# End rows (counting from bottom end of table) for the wetland types
group_end_rows = c(group_cum_rowcounts[1] + 2, 
			 group_cum_rowcounts[2] + 6, 
			 group_cum_rowcounts[3] + 10)

# The final rows on which to plot all data
group_rows = c(group_end_rows[3]:group_start_rows[3], 
		   group_end_rows[2]:group_start_rows[2], 
		   group_end_rows[1]:group_start_rows[1] 
) 

# Save plot
pdf("forest_regr_drain_slope_subgroups.pdf", height = 8)

# Print a forest plot of slopes
forest(result, slab = esd$Short_ref, 
	header = c("Author and year", "Slope [95% CI]"),
 	# ilab = esd$Ditch_spacing, ilab.xpos = -40, 
	ilab = esd$True_reps, ilab.xpos = -40,
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Slope", xlim = c(-95, 70)	
)	

op <- par(cex=.75, font=2)
text(-40, max(group_end_rows) + 3, "Wetlands")
text(-40, -1, sum(as.numeric(result$weights)), font = 1)

par(font = 4)
text(-95, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the three subgroups
res.b <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Bog"), yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
res.f <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Fen"), yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Unspecified peatland"), yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)

# Add summary polygons for the three subgroups
addpoly(res.b, row = group_start_rows[3] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
addpoly(res.f, row = group_start_rows[2] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)
text(-40, group_start_rows[3] - 1.5, sum(as.numeric(res.b$weights)), font = 1, cex = 0.75)
text(-40, group_start_rows[2] - 1.5, sum(as.numeric(res.f$weights)), font = 1, cex = 0.75)
text(-40, group_start_rows[1] - 1.5, sum(as.numeric(res.u$weights)), font = 1, cex = 0.75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("slope_main_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
df <- rbind(df, c("slope_main_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
df <- rbind(df, c("slope_main_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))


# Perform a meta-analysis of regression intercept
# -----------------------------------------------
# Calculate RE model based on underlying sample size (number of true replications) weights = True_reps
result = rma(measure = "MD", data = esd, yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("intercept_main_all", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Plotting 
# --------------------------------------------
# Save plot
pdf("forest_regr_drain_intercept_subgroups.pdf", height = 10)

# Print a forest plot of slopes
forest(result, slab = esd$Short_ref, 
	header = c("Author and year", "Intercept [95% CI]"),
 	ilab = esd$True_reps, ilab.xpos = -120, 
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Intercept" #, xlim = c(-160, 0)	
)	

op <- par(cex=.75, font=2)
text(-120, max(group_end_rows) + 3, "Wetlands")
text(-120, -1, sum(as.numeric(result$weights)), font = 1)

par(font = 4)
text(-220, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the three subgroups
res.b <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Bog"), yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
res.f <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Fen"), yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd, subset = (Wetland_type == "Unspecified peatland"), yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)

# Add summary polygons for the three subgroups
addpoly(res.b, row = group_start_rows[3] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
addpoly(res.f, row = group_start_rows[2] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)
text(-120, group_start_rows[3] - 1.5, sum(as.numeric(res.b$weights)), font = 1, cex = 0.75)
text(-120, group_start_rows[2] - 1.5, sum(as.numeric(res.f$weights)), font = 1, cex = 0.75)
text(-120, group_start_rows[1] - 1.5, sum(as.numeric(res.u$weights)), font = 1, cex = 0.75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("intercept_main_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
df <- rbind(df, c("intercept_main_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
df <- rbind(df, c("intercept_main_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))

# Sensitivity test - exclude blanket peatland studies 
# -----------------------------------------------
NoBlanketPeatlands = is.na(esd$"Blanket peatland")

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("slope_no_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))



# Plotting - slope and no blanket peatlands
# --------------------------------------------
# Count rows for each wetland type
# Needs to be adjusted for different number of groups
group_rowcounts = table(esd[NoBlanketPeatlands,]$Wetland_type)

# We want the cumulative no of rows in reverse alphabetical order for plotting (unspecified peatland, mire, fen, bog)
group_cum_rowcounts = cumsum(rev(group_rowcounts))

# Start rows (counting from bottom end of table) for the wetland types
group_start_rows = c(3, group_cum_rowcounts[1] + 7, 
				group_cum_rowcounts[2] + 11, 
				group_cum_rowcounts[3] + 15)

# End rows (counting from bottom end of table) for the wetland types
group_end_rows = c(group_cum_rowcounts[1] + 2, 
			 group_cum_rowcounts[2] + 6, 
			 group_cum_rowcounts[3] + 10)

# The final rows on which to plot all data
group_rows = c(group_end_rows[3]:group_start_rows[3], 
		   group_end_rows[2]:group_start_rows[2], 
		   group_end_rows[1]:group_start_rows[1] 
) 

# Save plot
pdf("forest_regr_drain_slope_no_blanket_peatlands.pdf", height = 8)

# Print a forest plot of slopes
forest(result, slab = esd[NoBlanketPeatlands,]$Short_ref, 
	header = c("Author and year", "Slope [95% CI]"),
 	ilab = esd[NoBlanketPeatlands,]$True_reps, ilab.xpos = -40, 
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Slope", xlim = c(-95, 70)	
)	

op <- par(cex=.75, font=2)
text(-40, max(group_end_rows) + 3, "Wetlands")
text(-40, -1, sum(as.numeric(result$weights)), font = 1)

par(font = 4)
text(-95, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the three subgroups
res.b <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Bog"), yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
res.f <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Fen"), yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Unspecified peatland"), yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)

# Add summary polygons for the three subgroups
addpoly(res.b, row = group_start_rows[3] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
addpoly(res.f, row = group_start_rows[2] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)
text(-40, group_start_rows[3] - 1.5, sum(as.numeric(res.b$weights)), font = 1, cex = 0.75)
text(-40, group_start_rows[2] - 1.5, sum(as.numeric(res.f$weights)), font = 1, cex = 0.75)
text(-40, group_start_rows[1] - 1.5, sum(as.numeric(res.u$weights)), font = 1, cex = 0.75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("slope_no_blanket_peatlands_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
df <- rbind(df, c("slope_no_blanket_peatlands_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
df <- rbind(df, c("slope_no_blanket_peatlands_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))



# Sensitivity test - intercept and exclude blanket peatland studies 
# -----------------------------------------------

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

# Add results to df for later export
df <- rbind(df, c("intercept_no_blanket_peatlands", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))




# Plotting - intercept and no blanket peatlands
# --------------------------------------------
# Save plot
pdf("forest_regr_drain_intercept_no_blanket_peatlands.pdf", height = 8)

# Print a forest plot of slopes
forest(result, slab = esd[NoBlanketPeatlands,]$Short_ref, 
	header = c("Author and year", "Intercept [95% CI]"),
 	ilab = esd[NoBlanketPeatlands,]$True_reps, ilab.xpos = -120, 
	cex = 0.75,
	rows = group_rows, ylim = c(-1, max(group_end_rows) + 4), 
	mlab = mlabfun("RE Model, all studies", result),
	digits = c(decimals_rows, decimals_axis),
	xlab = "Intercept" #, xlim = c(-95, 70)	
)	

op <- par(cex=.75, font=2)
text(-120, max(group_end_rows) + 3, "Wetlands")
text(-120, -1, sum(as.numeric(result$weights)), font = 1)

par(font = 4)
text(-225, group_end_rows + 1, pos = 4, rownames(rev(group_rowcounts)))
par(op)

# Fit random-effects model in the three subgroups
res.b <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Bog"), yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
res.f <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Fen"), yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
res.u <- rma(measure = "MD", data = esd[NoBlanketPeatlands,], subset = (Wetland_type == "Unspecified peatland"), yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)

# Add summary polygons for the three subgroups
addpoly(res.b, row = group_start_rows[3] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.b), digits = decimals_rows)
addpoly(res.f, row = group_start_rows[2] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.f), digits = decimals_rows)
addpoly(res.u, row = group_start_rows[1] - 1.5, cex=0.75, mlab = mlabfun("RE Model for subgroup", res.u), digits = decimals_rows)
text(-120, group_start_rows[3] - 1.5, sum(as.numeric(res.b$weights)), font = 1, cex = 0.75)
text(-120, group_start_rows[2] - 1.5, sum(as.numeric(res.f$weights)), font = 1, cex = 0.75)
text(-120, group_start_rows[1] - 1.5, sum(as.numeric(res.u$weights)), font = 1, cex = 0.75)

# Close graphics
dev.off() 

# Add results to df for later export
df <- rbind(df, c("intercept_no_blanket_peatlands_bog", res.b$b, res.b$se, res.b$ci.lb, res.b$ci.ub, res.b$k, res.b$pval, res.b$tau2, res.b$I2, res.b$H2, res.b$QE, res.b$QEp, NA, NA))
df <- rbind(df, c("intercept_no_blanket_peatlands_fen", res.f$b, res.f$se, res.f$ci.lb, res.f$ci.ub, res.f$k, res.f$pval, res.f$tau2, res.f$I2, res.f$H2, res.f$QE, res.f$QEp, NA, NA))
df <- rbind(df, c("intercept_no_blanket_peatlands_unspec", res.u$b, res.u$se, res.u$ci.lb, res.u$ci.ub, res.u$k, res.u$pval, res.u$tau2, res.u$I2, res.u$H2, res.u$QE, res.u$QEp, NA, NA))


# Tests of moderators - slope
# -------------------

# Investigate the possible influence of wetland type as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = ~factor(Wetland_type), test = "knha", weights = True_reps)
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_wetland_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of ditch spacing as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = cbind(Ditch_spacing), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_ditch_spacing", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of slope as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = cbind(Slope), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_slope", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Investigate the possible influence of peat depth as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = cbind(Peat_depth), test = "knha", weights = True_reps)
result  

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_peat_depth", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of time since intervention as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = cbind(Time_since_intervention_avg), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_time_since_intervention", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = cbind(Intervention_magnitude), test = "knha", weights = True_reps)
result 


pdf("regr_drain_mod_slope_metareg_intervention_magnitude.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(70,130), predlim=c(70,130), xlab="Intervention magnitude (cm)", ylab = "Slope coefficient value", legend = TRUE)
dev.off()

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_intervention_magnitude", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator when leaving out the outlier at 125 cm
result = rma(measure = "MD", data = esd[NoBlanketPeatlands & esd$Intervention_magnitude < 125,], yi = Regr_slope, sei = Regr_slope_SE, mods = cbind(Intervention_magnitude), test = "knha", weights = True_reps)
result 

pdf("regr_drain_mod_slope_metareg_intervention_magnitude_below_125_only.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(70,130), predlim=c(70,130), xlab="Intervention magnitude (cm)", ylab = "Slope coefficient value", legend = TRUE)
dev.off()

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_intervention_magnitude_below_125_only", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of open or closed transect as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps, mods = ~ factor(Transect_type))
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_transect_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Investigate the possible influence of underlying soil type as moderator
# For this test, group all "Till" studies into the same category, otherwise they are too few, and skip categories with one single study
esd_soils = data.frame(esd[NoBlanketPeatlands,])
# Remove a subgroup with only one single study
esd_soils <- esd_soils[!(esd_soils$"Underlying_soil" == "Sand or highly permeable soil"),]
esd_soils$Underlying_soil[esd_soils$Underlying_soil == "Low-permeability till" | esd_soils$Underlying_soil == "Unsorted till"] <- "Till"

# Check how many studies there are in each category
soil_type_counts = table(esd_soils$Underlying_soil)

result = rma(measure = "MD", data = esd_soils, yi = Regr_slope, sei = Regr_slope_SE, test = "knha", mods = ~factor(Underlying_soil) - 1, weights = True_reps)
result

# Save plot
pdf("regr_drain_mod_slope_soil_type.pdf", height = 4, width = 10)

# Plot soil type moderators
forest(result$b, sei = result$se, header = c("Underlying soil", "Slope [95% CI]"), 
									slab = c(rownames(soil_type_counts)[1], 
									 rownames(soil_type_counts)[2],
									 rownames(soil_type_counts)[3]
									),
				ilab = as.list(soil_type_counts), ilab.xpos = -50,
				xlim = c(-120, 30),
				# rows = c(2, 1, 4, 3),
				digits = c(decimals_rows, decimals_axis),
				xlab = "Slope", psize = 1

)
par(font=2)
text(-50, 6, "n")
dev.off() 



# Investigate the possible influence of soil type as moderator 
result = rma(measure = "MD", data = esd_soils, yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps, mods = ~ factor(Underlying_soil))
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_soil_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of climate zone as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps, mods = ~ factor(Climate_zone))
result

df <- rbind(df, c("slope_no_blanket_peatlands_moderator_climate_zone", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))






# Tests of moderators - intercept
# -------------------

# Investigate the possible influence of wetland type as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = ~factor(Wetland_type))
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_wetland_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of ditch spacing as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = cbind(Ditch_spacing))
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_ditch_spacing", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of slope as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = cbind(Slope))
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_slope", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of peat depth as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = cbind(Peat_depth))
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_peat_depth", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of time since intervention as moderator
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = cbind(Time_since_intervention_avg))
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_time_since_intervention", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of intervention magnitude as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = cbind(Intervention_magnitude))
result 

pdf("regr_drain_mod_intercept_metareg_intervention_magnitude.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(70,130), predlim=c(70,130), xlab="Intervention magnitude (cm)", ylab = "Intercept coefficient value")
dev.off()

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_intervention_magnitude", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Investigate the possible influence of intervention magnitude as moderator leaving out the outlier at 125 cm
result = rma(measure = "MD", data = esd[NoBlanketPeatlands & esd$Intervention_magnitude < 125,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = cbind(Intervention_magnitude))
result 

pdf("regr_drain_mod_intercept_metareg_intervention_magnitude_below_125_only.pdf", height = 5, width = 5)
regplot(result, mod = "Intervention_magnitude", xlim=c(70,130), predlim=c(70,130), xlab="Intervention magnitude (cm)", ylab = "Intercept coefficient value")
dev.off()

df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_intervention_magnitude_below_125_only", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Investigate the possible influence of open or closed transect as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = ~ factor(Transect_type) - 1)
result

pdf("regr_drain_mod_intercept_transect_type.pdf", height = 5, width = 5)
forest(result$b, sei = result$se, header = c("Transect type", "Intercept [95% CI]"),
	slab = str_replace(row.names(result$b), "factor\\(Transect_type\\)", ""),
	ilab = colSums(result$X), ilab.xpos = -65,
	digits = c(decimals_rows, decimals_axis),
	xlab = "Intercept", psize = 1, xlim = c(-140, 50)

)
par(font=2)
text(-65, dim(result$b)[1] + 2, "n")
dev.off()

# Investigate the factor as a whole
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = ~ factor(Transect_type) )
df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_transect_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Investigate the possible influence of underlying soil type as moderator
result = rma(measure = "MD", data = esd_soils, yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", mods = ~factor(Underlying_soil) - 1, weights = True_reps)
result

# Save plot
pdf("regr_drain_mod_intercept_soil_type.pdf", height = 4, width = 10)

# Plot soil type moderators
forest(result$b, sei = result$se, header = c("Underlying soil", "Slope [95% CI]"), 
									slab = c(rownames(soil_type_counts)[1], 
									 rownames(soil_type_counts)[2],
									 rownames(soil_type_counts)[3]
									),
				ilab = as.list(soil_type_counts), ilab.xpos = -150,
				xlim = c(-220, 30),
				# rows = c(2, 1, 4, 3),
				digits = c(decimals_rows, decimals_axis),
				xlab = "Slope", psize = 1

)
par(font=2)
text(-150, 6, "n")
dev.off() 


# Investigate the possible influence of soil type as moderator 
result = rma(measure = "MD", data = esd_soils, yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = ~ factor(Underlying_soil) )
df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_soil_type", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Investigate the possible influence of climate zone as moderator 
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = ~ factor(Climate_zone))
result
df <- rbind(df, c("intercept_no_blanket_peatlands_moderator_climate_zone", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))



# Sensitivity test - weighting method
# And Publication bias - funnel plots using SE weighting
# -----------------------------------------------

# Investigate if results are different if weight is based on standard error (how well study data fit a log regression function)
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha")
result 

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_weights_as_study_se", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Make a funnel plot of effect size vs study variance
pdf("regr_drain_funnel_slope.pdf", height = 4, width = 4)
funnel(result, xlab = "Slope")
dev.off() 

# Perform Egger's test of funnel plot assymetry
rt = regtest(result)
df <- rbind(df, c("slope_no_blanket_peatlands_eggers_test_weights_as_study_se", rt$est, NA, rt$ci.lb, rt$ci.ub, NA, rt$pval, NA, NA, NA, NA, NA, NA, NA))

# Perform trim and fill
taf = trimfill(result)
df <- rbind(df, c("slope_no_blanket_peatlands_trim_and_fill_est_missing_studies", taf$k0, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA))
df <- rbind(df, c("slope_no_blanket_peatlands_trim_and_fill_adjusted_weights_as_study_se", taf$b, taf$se, taf$ci.lb, taf$ci.ub, taf$k, taf$pval, taf$tau2, taf$I2, taf$H2, taf$QE, taf$QEp, NA, NA))


# Plot trim and fill results
pdf("regr_drain_funnel_slope_trim_and_fill.pdf", height = 4, width = 4)
funnel(taf, xlab = "Slope")
dev.off() 

# Also prepare the funnel plot without outliers
result = rma(measure = "MD", data = esd[NoBlanketPeatlands & esd$Regr_slope_SE < 5,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha")
pdf("regr_drain_funnel_slope_without_outliers.pdf", height = 4, width = 4)
funnel(result, xlab = "Slope")
dev.off() 



# Investigate if results are different if weight is based on standard error (how well study data fit a log regression function)
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha")
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_weights_as_study_se", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

# Make a funnel plot of effect size vs study variance
pdf("regr_drain_funnel_intercept.pdf", height = 4, width = 4)
funnel(result, xlab = "Intercept")
dev.off() 

# Perform Egger's test of funnel plot assymetry
rt = regtest(result)
df <- rbind(df, c("intercept_no_blanket_peatlands_eggers_test_weights_as_study_se", rt$est, NA, rt$ci.lb, rt$ci.ub, NA, rt$pval, NA, NA, NA, NA, NA, NA, NA))

# Perform trim and fill
taf = trimfill(result)
df <- rbind(df, c("intercept_no_blanket_peatlands_trim_and_fill_est_missing_studies", taf$k0, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA))

# Plot trim and fill results
pdf("regr_drain_funnel_intercept_trim_and_fill.pdf", height = 4, width = 4)
funnel(taf, xlab = "Intercept")
dev.off() 

# Also prepare the funnel plot without outliers
result = rma(measure = "MD", data = esd[NoBlanketPeatlands & esd$Regr_slope_SE < 5,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha")
pdf("regr_drain_funnel_intercept_without_outliers.pdf", height = 4, width = 4)
funnel(result, xlab = "Intercept")
dev.off() 


# Sensitivity test - remove studies with high risk of bias
# -----------------------------------------------
# Calculate RE model based on underlying sample size (number of true replications) weights = True_reps

# Test results when retaining only studies with at least four occurrences of "low risk of bias"
AtLeastFourLowRoB = rowSums(esd == "Low risk", na.rm = TRUE) > 3 & NoBlanketPeatlands

result = rma(measure = "MD", data = esd[AtLeastFourLowRoB,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_min_four_low_rob", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

result = rma(measure = "MD", data = esd[AtLeastFourLowRoB,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_min_four_low_rob", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))


# Sensitivity test - test influence of sampling distance from ditch
# -----------------------------------------------

# Investigate the possible sensitivity to maximum sampled distance
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_max_dist_for_gwl_sampling", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps, mods = ~ Max_dist_for_gwl_sampling)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_max_dist_for_gwl_sampling", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Sensitivity test - include only studies that measure absolute height against common datum and not vs ground surface level
# -----------------------------------------------
FixedRefLevel = esd$"Gwl_ref_point" == "Fixed point or common datum" # & NoBlanketPeatlands

# Test the factor as a whole
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = ~ factor(Gwl_ref_point), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_gwl_ref_point", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = ~ factor(Gwl_ref_point) - 1, test = "knha", weights = True_reps)
result 

df <- rbind(df, c("slope_no_blanket_peatlands_gwl_ref_point_fixed", result$b[1], result$se[1], result$ci.lb[1], result$ci.ub[1], result$k, result$pval[1], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))
df <- rbind(df, c("slope_no_blanket_peatlands_gwl_ref_point_ground_surface", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))
df <- rbind(df, c("slope_no_blanket_peatlands_gwl_ref_point_ground_surface_with_reference_height_reported", result$b[3], result$se[3], result$ci.lb[3], result$ci.ub[3], result$k, result$pval[3], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))

# Plot results
result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_slope, sei = Regr_slope_SE, mods = ~ factor(Gwl_ref_point) - 1, test = "knha", weights = True_reps)
result 

pdf("regr_drain_mod_slope_gwl_ref_point.pdf", height = 4, width = 12)
forest(result$b, sei = result$se, header = c("GWL reference point", "Slope [95% CI]"),
		slab = str_replace(row.names(result$b), "factor\\(Gwl_ref_point\\)", ""),
		ilab = colSums(result$X), ilab.xpos = -10,
		xlim = c(-85, 35), 
		digits = c(decimals_rows, decimals_axis),
		xlab = "Slope", psize = 1
)
par(font=2)
text(-10, 5, "n")
dev.off()

result = rma(measure = "MD", data = esd[NoBlanketPeatlands,], yi = Regr_intercept, sei = Regr_intercept_SE, mods = ~ factor(Gwl_ref_point), test = "knha", weights = True_reps)
result 

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_gwl_ref_point", result$b[2], result$se[2], result$ci.lb[2], result$ci.ub[2], result$k, result$pval[2], result$tau2, result$I2, result$H2, result$QE, result$QEp, result$QM, result$QMp))


# Sensitivity test - include only studies that measure absolute height against common datum and not vs ground surface level
# AND have at least four occurrences of "low risk of bias" for critical appraisal
# -----------------------------------------------
FixedRefLevelANDAtLeastFourLowRoB = FixedRefLevel & AtLeastFourLowRoB & NoBlanketPeatlands

result = rma(measure = "MD", data = esd[FixedRefLevelANDAtLeastFourLowRoB ,], yi = Regr_slope, sei = Regr_slope_SE, test = "knha", weights = True_reps)
result

df <- rbind(df, c("slope_no_blanket_peatlands_sensitivity_min_four_low_rob_gwl_ref_point_fixed", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))

result = rma(measure = "MD", data = esd[FixedRefLevelANDAtLeastFourLowRoB ,], yi = Regr_intercept, sei = Regr_intercept_SE, test = "knha", weights = True_reps)
result

df <- rbind(df, c("intercept_no_blanket_peatlands_sensitivity_min_four_low_rob_gwl_ref_point_fixed", result$b, result$se, result$ci.lb, result$ci.ub, result$k, result$pval, result$tau2, result$I2, result$H2, result$QE, result$QEp, NA, NA))


# Save meta-analysis results to file
write.xlsx(df, paste(output_dir, "meta-analysis_results_regr_drain.xlsx", sep = "/"))


